@@ -142,14 +142,16 @@ class Elbow:
 		"""
 		:rtype: int
 		"""
-		def _max(*args):
-			return max(*[x for x in args if x is not None])
 
-		return _max(
-			self.get_optimal_number_of_clusters(by='silhouette'),
-			self.get_optimal_number_of_clusters(by='inertia'),
-			self.get_optimal_number_of_clusters(by='distortion')
-		)
+		list_of_score_lists = []
+		for by in ['silhouette', 'inertia', 'distortion']:
+			try:
+				score_list = self.get_optimal_number_of_clusters(by=by)
+				list_of_score_lists.append(score_list)
+			except:
+				continue
+
+		return max(*list_of_score_lists)
 
 	@property
 	def records(self):
